Authors
==========================================

Developer
----------------

* `Bjørn-Jostein Singstad <https://github.com/bsingstad/>`_ *(Student, University of Oslo)*

Contributors
-------------

Do you want to be the first contributer to this project? Take a look at `these guides <https://ecg-featurizer.readthedocs.io/en/latest/contributing.html>`_). or send me a `mail <bjorn_sing@hotmail.com>`_).
